@@ -1,5 +1,7 @@
 timings_mean = function(timings) {
-  m = mean(timings[, 3])
+  ti = timings[,3]
+  ti = ti[ti > 0]
+  m = mean(ti)
   paste0(": ", signif(m, 3), " (sec).")
 }
 
